#ifndef _CLOCK_H
#define _CLOCK_H

#include "wx.h"
#include "wx_timer.h"
#include "Counter.h"

/* This class captures the concept of a simple timer. The granularity of
   the timer is in milliseconds. The granularity is specified when a
   Timer Object is "Start"ed. For example, for a timer object t, t.Start(100) 
   will Start the timer and set the granularity to 100 milliseconds (a tenth
   of a second).
*/

class Clock;

class ClockMechanism : public wxTimer {
private:
  char* clockName;
public:
  ClockMechanism(char* name);
  void Notify(void);
};

/* 
CLASS
   Clock

   This class captures the concept of a simple timer. The granularity of
   the timer is in milliseconds. The granularity is specified when a
   Clock object is constructed and can be changed by the <I>SetInterval</I>
   method.  The OnTimerEvent
   function is called at the end of each time interval with the name
   of the Clock object being passed as a parameter.
*/

class Clock {
private:
  ClockMechanism timer;
  int   clockInterval;
  char* clockName;
public:
  //////////
  // Construct a Clock with a given name and a give time interval. 
  //The Clock can be
  // started and stopped (it is initially stopped).
  //
  //<UL>
  //<LI><B>name </B>: the character string that will be passed as the
  // name of the Clock when the OnTimerEvent function is called.</LI>
  //<LI><B>interval </B>: the interval of time, measured in milliseconds
  // between calls to the OnTimerEvent function when the Clock is 
  //running. </LI>
  //</UL>
  Clock (char* name, int interval=1000);

  //////////
  // Change the interval of time used for the Clock.
  //<UL>
  //<LI><B>newInterval </B>: the new Clock interval (measured in
  //milliseconds.</LI>
  //</UL>
  void SetInterval(int newInterval);

  //////////
  // Start the Clock running.
  void Start();

  //////////
  // Stop the Clock. 
  void Stop();

  //////////
  // Is this the name of the Clock?
  //<UL>
  //<LI><B>name </B>: the character string that is compared to the
  // name given when the Clock object was constructed. A one (1) is
  // returned if the strings match and a zero (0) is returned
  // otherwise. </LI>
  //<UL>
  int  IsNamed(char* name);

  //////////
  // Destruct the Clock object.
  ~Clock();
};

#endif

