#ifndef _COUNTER_H
#define _COUNTER_H

#include "Message.h"

/*  
CLASS
    Counter
    
    This class captures the concept of a simple integer counter that
    counts upwards from a given, by default zero, initial value. A
    Counter object can be connected to a Message in which the counter
    will display its current value.
*/



class Counter {
private:
  int      initial, final, step;
  int      bounded;
  int      value;
  Message* message;

public:
  //////////
  // Construct a Counter object with an initial value and a maximum
  // value beyond which the Counter cannot be incremented. 
  //<UL>
  //<LI><B>start </B>: the initial value of the Counter</LI>
  //<LI><B>end </B>: the upper limit beyond which the Counter will
  // not allow itself to be increment.</LI>
  //</UL>
  Counter(int start, int end);

  //////////
  // Construct a Counter object with an initial value of zero and which
  // can be incremented without limit.
  Counter();

  //////////
  // Create an association between the Counter object and a Message object.
  // The text string equivalent of the Counter's object will be set in the
  // Message object.
  //<UL>
  //<LI><B>msg </B>: the associated Message object. When the value of
  // the Counter changes, the text string in the Message will be changed
  // to maintain the invariant that the text string always reflects the
  // current value of the Counter.</LI>
  //</UL>
  void ConnectTo(Message& msg);

  //////////
  // Advance the Counter to its next value. The operation has no effect
  // if the Counter is at its maximum value.
  void Next();

  //////////
  // Set the Counter back to its original (initial) value.
  void Reset();

  //////////
  // Reclaim all resources associated with the Counter.
 ~Counter();

};


#endif


