#ifndef _PROGRAM_H
#define _PROGRAM_H

//////////
//
//  The simple programming environment is defined by four functions. 
//  Each of the four functions in the simple programming environment 
//  MUST be defined, even if the body of the function contains no code.
//
//  The Program.h include file defines four constants that describe
//  the state of the mouse buttons when a mouse event occurs. These
//  constants are used in the OnMouseEvent function's <I>buttonState</I>
//  parameter.
enum MouseState { leftButtonDown   = 1,
                  rightButtonDown  = 2,
                  middleButtonDown = 4,
                  isDragging       = 8 };
//////////
//This function is called exactly once when the "Start" button
//in the start window is pressed. This function is used to initialize
//the system. 
void OnStart(void);

//////////
//This function is called whenever a mouse event occurs within a
//   user-defined Frame. The identity of the frame, the coordinates of
//   the mouse position, and the state of the mouse buttons are passed
//   as parameters.
//<UL>
//<LI><B>frame</B>: this string defines the name of the frame in which
//           the mouse event occurred. The name of the frame was given in
//           the Frame constructor.</LI>
//<LI><B> x</B>: the x coordinate (with respect to the upper left-hand
//           corner of where the mouse was located when the mouse event
//           occurred.</LI>
//<LI><B> y</B>: the y coordinate (with respect to the upper left-hand
//           corner of where the mouse was located when the mouse event
//           occurred.</LI>
//<LI><B> buttonState</B>: the condition of the mouse buttons at the
//           time of the mouse event. The possible values for this integer
//           variable are given by the four defined constants 
//           <I> leftButtonDown</I>, <I> rightButtonDown</I>,   
//           <I> middleButtonDown</I>, and <I> isDragging</I>.
void OnMouseEvent(char *frame, int x, int y, int buttonState);

//////////
//This function is called whenever the timer has been started by the
//       user (using the Timer pulldown menu in the start window of the
//       simple programming environment) and the timer has reached the end
//       of the current timer interval. The timer interval can be changed
//       by the slider control in the start window. The function is called
//       repeatedly, at the end of each timer interval, as long as the timer
//       is turned on. The timer may be turned off by using the Timer
//       pulldown menu in the start window.
void OnTimerEvent(void);

//////////
//This function is called whenever the system suspects that the
//       contents of a window may need to be refreshed (redrawn) due to
//       actions in the user interface (e.g,  by moving a window
//       that was obscuring part of a lower window, requiring the lower
//       (previously obscured) window to be redrawn).
void OnPaint(void);


#endif
