#ifndef _FRAME_H
#define _FRAME_H

#include "wx.h"
#include "BscFrame.h"
#include "Location.h"
#include "Shape.h"


class Message;
class BlinkingMessage;

/* This class captures the concept of a framed window that appears on
   a graphical user interface. A Frame object is named so that mouse
   events can be associated with a given Frame. A Frame can be manipulated 
   by the program to change its location and shape. A Frame can display
   text and be erased.

*/



class Frame {
private:

   char       *name;
   BasicFrame *frame;
   Location    location;
   Shape       shape;

   void CreateIfNeeded();
   

public:

   Frame(char *name, Location loc, Shape sh);
   Frame(char* name, Location loc);
   Frame(char* name, Shape sh);
   Frame(char* name);
   Frame();
  ~Frame();
            
   void     MoveTo(Location loc);               // change position
   void     Resize(Shape sh);                   // change shape
   void     Resize( float factor);              //
   void     DrawText(char* msg, Location loc);  // display msg at (x,y)
   Shape    TextSize (char* msg);               // find size of msg
   void     DrawLine(Location p1,               // draw line from point p1
                     Location p2);              //           to   point p2
   void     DrawCircle(Location center, int r); // draw circle with radius r
                                                // atcenter 
   void     Clear();                            // clear entire display area
   void     Clear(Location loc, Shape sh);      // clear selected region
   int      IsNamed(char* n);                   // is this your name?
};


#endif







