#include "Frame.h"
#include "BscFrame.h"
#include "wx.h"


void Frame::CreateIfNeeded() {
 if (!frame) {
      frame = new BasicFrame( name, location.Xcoord(), location.Ycoord(),
                                    shape.Width(), shape.Height(), this );
      frame->Show(TRUE); 
   }
}

Frame::Frame(char *nm, Location loc, Shape sh) {
     name     = copystring(nm); 
     location = loc;
     shape    = sh;
     frame    = (BasicFrame*)0; 
}

Frame::Frame(char *nm, Location loc) {
     name     = copystring(nm); 
     location = loc;
     shape    = Shape(100,100);
     frame    = (BasicFrame*)0; 
}
  
Frame::Frame(char *nm, Shape sh) {
     name     = copystring(nm); 
     location = Location(100,100);
     shape    = sh;
     frame    = (BasicFrame*)0; 
}
  
  
Frame::Frame(char *nm) {
     name   = copystring(nm); 
     location = Location(100,100);
     shape    = Shape(100,100);
     frame  = (BasicFrame*)0; 
}

Frame::Frame() {
     name = "NoName";
     location = Location(100,100);
     shape    = Shape(100,100);
     frame  = (BasicFrame*)0; 
} 
        
Frame::~Frame() {
     // Here's a memory leak.  unfortunately, if we
     // leave it in, certain OSs crash a lot.  go figure.
     // if (frame) delete frame;
}

void Frame::MoveTo(Location loc ) {
       CreateIfNeeded();
       location = loc;
       frame->SetSize( loc.Xcoord(),  loc.Ycoord(),
                       shape.Width(), shape.Height());
}

void Frame::Resize(Shape sh) {
       CreateIfNeeded();        
       shape = sh;
       frame->SetSize( location.Xcoord(), location.Ycoord(),
                       sh.Width(), sh.Height());
}

void Frame::Resize(float factor) {
       CreateIfNeeded();
       shape = Shape((int)(shape.Width()*factor), 
                    (int)(shape.Height()*factor));
       frame->SetSize( location.Xcoord(), location.Ycoord(),
                       shape.Width(), shape.Height());
}

void Frame::DrawText(char *msg, Location loc) 
{
    CreateIfNeeded();
    frame->canvas->DrawText(msg, (float)loc.Xcoord(), 
                                 (float)loc.Ycoord());
}


Shape Frame::TextSize(char *msg) 
{
    float wf, hf, descent, leading;
    CreateIfNeeded();
    wxCanvasDC* dc = frame->canvas->GetDC();
    dc->GetTextExtent(msg, &wf, &hf, &descent, &leading);
    return Shape((int)wf, ((int)hf)+1);
}



void Frame::Clear() 
{
    CreateIfNeeded();
    frame->canvas->Clear();
}

void Frame::Clear(Location loc, Shape sh) 
{
    CreateIfNeeded();
    frame->canvas->SetClippingRegion((float)loc.Xcoord(),
                                     (float)loc.Ycoord(),
                                     (float)sh.Width(),
                                     (float)sh.Height());
    frame->canvas->Clear();
    frame->canvas->DestroyClippingRegion();
}

void Frame:: DrawLine(Location p1, Location p2) 
{
    CreateIfNeeded();
    frame->canvas->DrawLine((float)(p1.Xcoord()), (float)(p1.Ycoord()),
                            (float)(p2.Xcoord()), (float)(p2.Ycoord()));
}

void Frame::DrawCircle(Location center, int r)
{
    CreateIfNeeded();
    frame->canvas->DrawEllipse((float)(center.Xcoord()-r), 
                               (float)(center.Ycoord()-r), 
                               (float)(2*r), (float)(2*r));
}

int Frame::IsNamed(char *nm) {
   if (strcmp(name, nm) == 0) return 1;
   return 0;
 }





