#ifndef _FILENAVIGATOR_H
#define _FILENAVIGATOR_H

#include "File.h"

/*
CLASS
   FileNavigator

  This class initiates a modal dialogue with the user to obtain a
  File. The user is presented with a dialogue box which
  shows all the names of files in a specified directory that match a given
  filter pattern. The user is able to navigate to higher and lower
  directories in the file system in search of the desired File. 

*/

class FileNavigator {
private:

   char* thisPath;
   char* thisFilter; 

public:
     //////////
     // Construct a FileNavigator object that will, when the dialogue is
     // initiated, begin the navigation at the specified directory and using
     // the specified filter pattern.
     //<UL>
     //<LI><B>path</B>: the pathname of the original directory whose
     // filtered filenames are presented to the user. </LI>
     //<LI><B>filer</B>: the filter string which filenames must match
     // to be shown to the user.</LI>
     //</UL>
     FileNavigator(char* path, char* filter);   

     //////////
     // Construct a FileNavigator object that will, when the dialogue is
     // initiated, begin the navigation at the specified directory.
     //<UL>
     //<LI><B>path</B>: the pathname of the original directory whose
     // unfiltered filenames are presented to the user.</LI>
     //</UL>
     FileNavigator(char* path);                 

     //////////
     // Construct a FileNavigator object that will, when the dialogue is
     // initiated, begin the navigation at the user's current working
     // directory. No filtering of filenames is done.
     FileNavigator();  
                         
   //////////
   // Initiate the dialogue. This method does not return until the
   // user has dismissed the dialogue box. The method returns a File
   // object describing the result of the users action.
File AskUser();                                 

   //////////
   // Reclaim all resources associated with the FileNavigator object when
   // the object is destructed.
    ~FileNavigator();                           
};

#endif
