#ifndef _LOCATION_H
#define _LOCATION_H



class Frame;

/* 
CLASS
   Location

   This class defines the concepts of a Location in a coordinate system
   where the (0,0) position is in the upper left-hand corner. The x-axis
   extends in a positive direction to the right and the y-axis extends in
   a positive direction towards the bottom of the screen.
*/

class Location {			 // Version 2
private:  

     int  currentX, currentY;

public:

     //////////
     // Construct a Location object with the specified x and y coordinates.
     // <UL>
     // <LI><B>x </B>: the x coordinate of the location.
     // <LI><B>y </B>: the y coordinate of the location.
     // </UL>
	Location(int x, int y);	
        
     //////////
     // Construct a Location object at a default location.
        Location();	
		
     //////////
     // Return the current x coordinate of the Location object.
     int Xcoord();   
    		
     //////////
     // Return the current y coordinate of the Location object.
     int Ycoord();  
      		
     //////////
     // Create and return a new Location object that differs from the
     // existing Location object by the specified amount in the x
     // coordinate. The <I>amount</I> may be positive or negative.
     // The method does not change the existing Location object.
     //<UL>
     //<LI><B>amount</B>: the integer adjustment may to the existing
     // Location object's x coordinate. </LI>
     //</UL>
     Location Xmove(int amount);        
                                        
     //////////
     // Create and return a new Location object that differs from the
     // existing Location object by the specified amount in the y
     // coordinate. The <I>amount</I> may be positive or negative.
     // The method does not change the existing Location object.
     //<UL>
     //<LI><B>amount</B>: the integer adjustment may to the existing
     // Location object's y coordinate. </LI>
     //</UL>
     Location Ymove(int amount);        
                                        
};

#endif




