#ifndef _PRIMMSG_
#define _PRIMMSG_

/*
CLASS
   PrimitiveMessage

   This class defines a minimal abstraction of a text-bearing
   message. The class provides method to set and retrieve the
   text that is part of the message but is unable to provide
   any higher-level handling of the text. The PrimitiveMessage
   object always maintains its own private copy of the text 
   string so that its value is unaffected by changes to text
   strings outside of the PrimitiveMessage object. 
*/

class PrimitiveMessage {

private:
	char* msgText;

public:

        //////////
        // Construct a PrimitiveMessage object with a given
        // text string.
        //<UL>
        //<LI><B>text</B>: the text string that is held by the
        //PrimitveMessage object.</LI>
        //</UL>
	PrimitiveMessage(char* text);

        //////////
        // Change the text string of the object to a new text string.
        //<UL>
        //<LI><B>newText</B>: the text string of the PrimitveMessage 
        // object is set to this text string.</LI>
        //</UL>
	void SetText(char* newText);

        //////////
        // Return the current text string of the PrimitiveMessage
        // object. A copy of the text string held by the object is
        // returned (so the return string can be altered or deleted
        // without changing the text string of the PrimitiveMessage.
	char* GetText();

        //////////
        // Reclaim the resources (the text string) that is associated
        // with the object being deleted.
	~PrimitiveMessage();
};


#endif
