#ifndef _SHAPE_H
#define _SHAPE_H


/* 
CLASS
   Shape

   This class captures the concepts of the shape of a rectangular
   graphical user interface item (e.g, a window object). Shape
   objects are used to describe the dimensions of the visible
   window of a Frame, and an area within a Frame's visible window.
*/


class Shape {			// Version 2
private:  
   int currentWidth, currentHeight;
public:   

     //////////
     // Construct a Shape object with the specified width and height.
     // <UL>
     // <LI><B>width </B>: the width  of the shape.
     // <LI><B>height </B>: the height of the shape.
     // </UL>
	Shape(int width, int height);	

     //////////
     // Construct a Shape object with default height and width.
	Shape();         		

     //////////
     // Return the current height  of the Shape object.
     int Height();              	

     //////////
     // Return the current width of the Shape object.
     int Width();               	

     //////////
     // Construct and return a new Shape object whose width (height) differs 
     // from that of the existing Shape object's width (height) by the
     // the specified multiplicative <I>factor</I>. If the factor exceeds
     // 1.0, the returned Shape is larger than the existing Shape. If the
     // factor is below 1.0, the returned Shape is smaller than the
     // existing Shape. This method does not change the existing Shape
     // object's dimesions.
     //<UL>
     // <LI> <B>factor</B>: the factor by which the width and the height
     // are multiplied to compute the dimensions of the returned Shape
     // object. </LI>
     // </UL>
     Shape Resize(float factor);        
                                        
                                        

};

#endif





