#ifndef _FRAME_H
#define _FRAME_H

#include "wx.h"
#include "BscFrame.h"
#include "Location.h"
#include "Shape.h"



/* This class captures the concept of a framed window that appears on
   a graphical user interface. A Frame object is named so that mouse
   events can be associated with a given Frame. A Frame can be manipulated 
   by the program to change its location and shape. A Frame can display
   text and be erased.

*/


class Frame {
private:

   char       *name;
   BasicFrame *frame;
   Location    location;
   Shape       shape;

   void CreateIfNeeded();
   friend class Canvas;
   friend class Panel;
public:

   Frame(char *name, Location loc, Shape sh);
   Frame(char* name, Location loc);
   Frame(char* name, Shape sh);
   Frame(char* name);
   Frame();
  ~Frame();
       
   void     MoveTo(Location loc);               // change position
   void     Resize(Shape sh);                   // change shape
   void     Resize( float factor);              // grow/shrink by factor

   int      IsNamed(char* n);                   // is this your name?
};


#endif







