#ifndef _BUTTON_H_
#define _BUTTON_H_

#include "wx.h"
#include "Location.h"
#include "Shape.h"

/*
CLASS
     Button

  This class captures the abstraction of a pushable control in the
  user interface. Each button has a name that defines the text
  appearing on the face of the button. The name suggests the action
  associated with the button being pushed. When the button is pushed,
  the OnPush function of the simple programming environment is called
  with the name of the button as a parameter. By testing this name,
  the identity of the pushed button can be determined.
  A button appears at a
  specified Location within a Panel and occupies a region defined by
  a Shape. A button is added to a Panel using a method defined in
  the Panel class.
  
*/

class Button {
 private:
   wxButton *wxb;
   char *buttonName;
   Location location;
   Shape shape;
   void CreateIfNeeded(wxPanel* panel);
   friend class Panel;
 public:
   //////////
   // Construct a button object with the specified name, Location, and
   // Shape. The Shape must be sufficiently large to contain the characters
   // of the name. 
   //<UL>
   //<LI><B>name </B>: the name that appears on the face of the button
   // in the user interface; also passed to the OnPush function when
   // the button is pushed by the user.</LI>
   //<LI><B>location </B>: the position in a Panel of the upper
   // left-hand corner of the button.</LI>
   //<LI><B>shape </B>:  the rectangular area occupied by the button
   // in a Panel.</LI>
   //</UL>
   Button(char* name, Location location, Shape shape);

   //////////
   // Determine if the name of the button matches a given text string.
   // Return 1 if the given text string matches the button's name, 
   // otherwise return 0.
   int IsNamed(char* name);

  //////////
  // Release all resources owned by the Button's implementation.
 ~Button();
 };

#endif




