#ifndef _LOCATIONNODE_H
#define _LOCATIONNODE_H

#include "Location.h"

/*
CLASS
  LocationNode
  
  This class is a utility object that allows  Location
  objects to be linked together to form a list without modifying
  the code of the Location class (e.g., to insert a pointer to
  the next element in the list). Each LocationNode contains a
  pointer to a Location object that it represents in the list, 
  and a pointer to the next LocationNode in the list. 
*/

class LocationNode
{private:
   LocationNode *next;
   Location *location;
 public:

    //////////
    // Construct a LocationNode representing a given Location object.
    //<UL>
    //<LI><B> loc </B>: a pointer to the Location object represented
    // by this LocationNode </LI>
    //</UL>
    LocationNode(Location *loc);

    //////////
    // Return a pointer to the next LocationNode in the list.
    LocationNode* Next();

    //////////
    // Set the current LocationNode object to point to a given
    // LocationNode as its successor in the linked list.
    //<UL>
    //<LI><B>nxt </B>: a pointer to the LocationNode object that
    // is to be the successor of the current LocationNode. </LI>
    //</UL>
    void Next(LocationNode* nxt);

    //////////
    // Return the Location object represented by the the current
    // LocationNode. The Location object is returned by reference
    // so that methods may be applied directly to the Location object.
    Location& Contents();

    //////////
    // This destructor deletes the Location object pointed to by
    // the current LocationNode. It does NOT delete its successor
    // LocationNode in the list.
   ~LocationNode();
};

#endif

