#ifndef _PANEL_H_
#define _PANEL_H_

#include "wx.h"
#include "Frame.h"
#include "Button.h"
#include "TextBox.h"
#include "Location.h"
#include "Shape.h"

/*
CLASS
  Panel

  This class captures the abstraction of a "control panel" - a region
  within a Frame that contains interactive controls. Two types of 
  interactive controls can be placed in a Panel: Button objects and 
  TextBoxes objects.
  
*/

class Panel {
 private:
   wxPanel       *wxp;          // hidden wxPanel object
   char          *name;        
   Location       location;
   Shape          shape;
   Frame         *frame;       // Frame to which this is attached
   void CreateIfNeeded();
 public:

   //////////
   // Construct a Panel as a region within an existing Frame. In 
   // addition to the Panel's name, the Location within
   // the Frame and the Shape of the Canvas are specified. It is
   // important that the Frame be of sufficient size so that the 
   // Panel's position  and dimensions allow the Panel to be  
   // entirely contained within the Frame.
   //<UL>
   //<LI><B>frame </B>: the Frame object in which the Panel will appear.</LI>
   //<LI><B>name </B>: the name of the Panel. </LI>
   //<LI><B>location </B>: the position in the Frame of the upper left-hand 
   // corner of the Panel's rectangular region. </LI>
   //<LI><B>shape </B>: the dimensions of the Panel.</LI>
   //</UL>
   Panel(Frame& frame, char *name, Location location, Shape shape);

   //////////
   // Return the name of the Panel. The name of the Panel is
   // defined by the Panel's constructor. 
   char* getName();

   //////////
   // Add the specified Button to the Panel. Any number of Button objects (and
   // TextBox objects) may be added to the Panel provided that their
   // placement and size does not cause them to overlap within the Panel.
   //<UL>
   //<LI><B>button </B>: the Button object being added to the Panel.</LI>
   //</UL>
   void Add(Button& button);

   //////////
   // Add the specified TextBox to the Panel. Any number of TextBox objects 
   // (and Button objects) may be added to the Panel provided that their
   // placement and size does not cause them to overlap within the Panel.
   //<UL>
   //<LI><B>tbox </B>: the Textbox object being added to the Panel.</LI>
   //</UL>
   void Add(TextBox& tbox);

  ~Panel();
 };

#endif
