#ifndef _RECTANGLE1_H
#define _RECTANGLE1_H

#include "Location.h"
#include "Shape.h"
#include "Canvas.h"

/*
CLASS
  Rectangle1

  This class represents a rectangular shape. The dimensions and initial
  position of the Rectangle within a Canvas are specified when the   
  rectangle is constructed. The rectangle may be moved relative to its
  current positions, drawn, and erased. Note: the name of the class has
  a suffixed digit to differentiate it from two variations (Rectangle2
  and Rectangle3) of this class and because the name "Rectangle"
  conficts with predefined names on some systems.

*/

class Rectangle1
{
  private:
	  Location upperLeft;
	  Location upperRight;
	  Location lowerLeft;
	  Location lowerRight;
	  Shape    area;

  public:
     
          //////////
          // Construct a rectangle object that represents a rectangular
          // shape at a given position.
          //<UL>
	  //<LI><B>corner </B>: the Location of the upper left-hand
          // corner of the rectangle</LI>
	  //<LI><B>shape </B>: the dimesions (width and height) of the
          // Rectangle.</LI>
          //</UL>
	  Rectangle1 (Location corner, Shape shape);

          //////////
          // Move the Location of the Rectangle a given amount toward
          // the top edge of the Canvas relative to its current
          // position.
          //<UL>
	  //<LI><B>deltaY </B>: the amount to move the Rectangle toward
          // the top edge from its current position.</LI>
          //</UL>
	  void MoveUp    (int deltaY);

          //////////
          // Move the Location of the Rectangle a given amount toward
          // the bottom edge of the Canvas relative to its current
          // position.
          //<UL>
	  //<LI><B>deltaY </B>: the amount to move the Rectangle toward
          // the bottom edge from its current position.</LI>
          //</UL>
	  void MoveDown  (int deltaY);

          //////////
          // Move the Location of the Rectangle a given amount toward
          // the left edge of the Canvas relative to its current
          // position.
          //<UL>
	  //<LI><B>deltaS </B>: the amount to move the Rectangle toward
          // the left edge from its current position.</LI>
          //</UL>
	  void MoveLeft  (int deltaX);

          //////////
          // Move the Location of the Rectangle a given amount toward
          // the right edge of the Canvas relative to its current
          // position.
          //<UL>
	  //<LI><B>deltaX </B>: the amount to move the Rectangle toward
          // the right edge from its current position.</LI>
          //</UL>
	  void MoveRight (int deltaX);


          //////////
          // Draw the Rectangle at its current position in a given
          // Canvas.
          //<UL>
	  //<LI><B>canvas </B>: the Canvas in which the Rectangle
          //is drawn.</LI>
          //</UL>
	  void Draw(Canvas& canvas);

          //////////
          //  Erase the Rectangle from the given Canvas in which it
	  // is drawn. Note: no check is made that the Rectangle
          // is actually drawn in this Canvas; it is the programmer's
          // responsibility to insure this condition.
          //<UL>
	  //<LI><B>canvas</B>: the Canvas from which the Rectangle
          // is to be erased.</LI>
          //</UL>
	  void Clear(Canvas& canvas);

          //////////
          // Release the resources held by the Rectangle object.
	  ~Rectangle1();
};

#endif
