#ifndef _CANVAS_H
#define _CANVAS_H

#include "wx.h"
#include "Location.h"
#include "Shape.h"
#include "Frame.h"
#include "Color.h"

class Canvas;
class BasicFrame;

void OnPaint();

class DrawingCanvas: public wxCanvas
{
    Canvas *canvas;

  public:
    DrawingCanvas(BasicFrame *frame, Canvas* cvs, int x, int y, int w, int h, 
                              long style = wxRETAINED);
    ~DrawingCanvas(void) ;
    void OnPaint();
    void OnEvent(wxMouseEvent& event);
};


class Canvas {
 private:
   DrawingCanvas *dc;          // hidden drawing area
   char          *name;        
   Location       location;
   Shape          shape;
   Frame         *frame;       // Frame to which this is attached

   void CreateIfNeeded();
   
 public:
   Canvas(Frame& fr, char *nm, Location loc, Shape sh);
   void     SetDrawColor(Color color);
   void     SetFillColor(Color color);
   void     DrawText(char* msg, Location loc);  // display msg at loc
   Shape    TextSize (char* msg);               // find size of msg
   void     DrawLine(Location p1,               // draw line from point p1
                     Location p2);              //           to   point p2
   void     DrawCircle(Location center, int r); // draw circle with radius r
                                                // at center 
   void     Clear();                            // clear entire display area
   void     Clear(Location loc, Shape sh);      // clear selected region
   char*    getName();                          // what is your name?
  ~Canvas();
 };





#endif






